@@ -246,7 +246,7 @@ class FObject(FMasterDetail):
 			'name','description','owner','group_id','permissions',\
 			]
 	def getDetailReadOnlyColumnNames(self):
-		return ['creator','creation_date','last_modify','last_modify_date','deleted_by','deleted_date',]
+		return ['id','creator','creation_date','last_modify','last_modify_date','deleted_by','deleted_date',]
 	def getFilterFields(self):
 		return ['name','description','owner','group_id',]
 	def getListTitle(self):
@@ -1179,7 +1179,7 @@ class FTodo(FObject):
 	def getFilterForm(self):
 		return FTodoFilter()
 	def getFilterFields(self):
-		return ['name','priority','data_segnalazione','fk_segnalato_da','fk_cliente','fk_progetto','father_id','fk_tipo','stato','stato','data_chiusura']
+		return ['name','priority','data_segnalazione','fk_segnalato_da','fk_cliente','fk_progetto','father_id','fk_tipo','stato','data_chiusura']
 	def getListTitle(self):
 		return 'Tasks'
 	def getListColumnNames(self):
