@@ -39,7 +39,7 @@ except AttributeError:
 import explorerwidgetui
 from rprj.formulator import FAssociation
 
-DEBUG_WIDGET=False
+DEBUG_WIDGET=True
 
 class ExplorerWidget(QtGui.QWidget):
 	def __init__(self,parent,objectName):
@@ -236,24 +236,30 @@ class ExplorerWidget(QtGui.QWidget):
 		self.ui.treeView.setCurrentIndex( self.modelTree.indexFromItem(myparent) )
 	def updateTree(self,lista):
 		self.modelTree.clear()
-		self.previousItem = None
-		for l in lista:
-			_mytypename = l.getTypeName()
-			if _mytypename=='DBEObject':
-				_mytypename=l.getValue('classname')
-			myform = self.formFactory.getInstanceByDBEName( _mytypename, dbmgr=self.server)
-			icon = QtGui.QIcon()
-			icon.addPixmap(QtGui.QPixmap(_fromUtf8(":/rPrj/%s"%myform.getDetailIcon())), QtGui.QIcon.Normal, QtGui.QIcon.Off)
-			item = QtGui.QStandardItem( icon, "%s" % (l.getValue('name')) )
-			item.setData(l)
-			desc = l.getValue('description')
-			if desc>'':
-				item.setToolTip( desc )
-			self.modelTree.appendRow( item )
+		# 2012.11.11: start.
+		self.ids_items={}
+		self.fatherids_items={}
+		rootItem = self.modelTree.invisibleRootItem()
+		self.updateItem(rootItem, lista)
+		#for l in lista:
+			#_mytypename = l.getTypeName()
+			#if _mytypename=='DBEObject':
+				#_mytypename=l.getValue('classname')
+			#myform = self.formFactory.getInstanceByDBEName( _mytypename, dbmgr=self.server)
+			#icon = QtGui.QIcon()
+			#icon.addPixmap(QtGui.QPixmap(_fromUtf8(":/rPrj/%s"%myform.getDetailIcon())), QtGui.QIcon.Normal, QtGui.QIcon.Off)
+			#item = QtGui.QStandardItem( icon, "%s" % (l.getValue('name')) )
+			#item.setData(l)
+			#desc = l.getValue('description')
+			#if desc>'':
+				#item.setToolTip( desc )
+			#self.modelTree.appendRow( item )
+		# 2012.11.11: end.
 		self.modelTree.setHorizontalHeaderItem( 0, QtGui.QStandardItem("Name") )
 		# TODO connect this signal to the first 8 lines of code in rPrj.updateTree
 		self.emit(QtCore.SIGNAL("updatedTree()"))
 	def updateItem(self,item,lista):
+		rootItem = self.modelTree.invisibleRootItem()
 		for l in lista:
 			_mytypename = l.getTypeName()
 			if _mytypename=='DBEObject':
@@ -266,7 +272,30 @@ class ExplorerWidget(QtGui.QWidget):
 			desc = l.getValue('description')
 			if desc>'':
 				child.setToolTip( desc )
-			item.appendRow( child )
+			# 2012.11.11: start.
+			self.ids_items[l.getValue('id')]=child
+			if l.getValue('father_id')>'':
+				if not self.fatherids_items.has_key(l.getValue('father_id')):
+					self.fatherids_items[l.getValue('father_id')]=[]
+				self.fatherids_items[l.getValue('father_id')].append(child)
+			# 1. Check whether I'm son of somebody
+			father_id = l.getValue('father_id')
+			parentItem = None
+			if father_id>'' and self.ids_items.has_key(father_id):
+				parentItem = self.ids_items[father_id]
+			#if father_id>'':
+				#parentItem = self._findItemById(father_id)
+			if not parentItem is None and not parentItem==rootItem and not parentItem==item:
+				parentItem.appendRow( child )
+				self.ui.treeView.setExpanded(parentItem.index(),True)
+			else:
+				item.appendRow( child )
+			# 2. Check whether my childs are already here
+			if self.fatherids_items.has_key(l.getValue('father_id')):
+				mychilds = self.fatherids_items[l.getValue('father_id')]
+				if len(mychilds)>0: print "TODO: che fare con i %s childs?"%len(mychilds)
+			#item.appendRow( child )
+			# 2012.11.11: end.
 		self.ui.treeView.setExpanded(item.index(),True)
 	def _findItemById(self,uuid,rootItem=None):
 		if rootItem is None:
