@@ -36,6 +36,39 @@ except AttributeError:
 
 DEBUG_WIDGET=True
 
+class SearchWidgetItemDelegate(QtGui.QItemDelegate):
+	# http://doc.qt.digia.com/qt/model-view-programming.html
+	# http://doc.qt.digia.com/qt/qabstractitemview.html#setItemDelegate
+	# QItemDelegate(QObject parent=None)
+	def __init__(self,myfield, parent=None):
+		QtGui.QItemDelegate.__init__(self,parent)
+		#self.myeditorclazz = myeditorclazz
+		self.myfield = myfield
+	
+	# QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const;
+	def createEditor(self, parent, option, index):
+		#self.myinstance = self.myeditorclazz()
+		editor = self.myfield.InitField(parent)
+		#editor.setMinimum(0)
+		#editor.setMaximum(100)
+		return editor
+	
+	# void setEditorData(QWidget *editor, const QModelIndex &index) const;
+	def setEditorData(self, editor, index):
+		value = index.model().data(index, QtCore.EditRole).toInt()
+		#QSpinBox *spinBox = static_cast<QSpinBox*>(editor)
+		spinBox = editor
+		spinBox.setValue(value)
+
+	# void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const;
+	def setModelData(self, editor, model, index):
+		value = editor.getValue()
+		model.setData(index, value, QtCore.EditRole) # Qt.EditRole
+	
+	# void updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option, const QModelIndex &index) const;
+	def updateEditorGeometry(self, editor, option, modelindex):
+		editor.field.setGeometry(option.rect)
+
 class SearchWidget(QtGui.QWidget):
 	def __init__(self,parent,objectName,filterForm,modifyFilter=True):
 		QtGui.QWidget.__init__(self,parent)
@@ -62,9 +95,19 @@ class SearchWidget(QtGui.QWidget):
 		self.widgetList = QtGui.QTableView(self)
 		self.widgetList.setSortingEnabled(True)
 		self.columnNames = self.filterForm.getListColumnNames()
-		self.model = QtGui.QStandardItemModel(0, len(self.columnNames), self.widgetList)
+		self.model = QtGui.QStandardItemModel(0, len(self.columnNames)+1, self.widgetList)
+		self.model.setHeaderData(0, QtCore.Qt.Horizontal, QtCore.QVariant( "Type" ))
 		for i in range(len(self.columnNames)):
-			self.model.setHeaderData(i, QtCore.Qt.Horizontal, QtCore.QVariant( self.filterForm.getField( self.columnNames[i] ).GetTitle() ))
+			self.model.setHeaderData(i+1, QtCore.Qt.Horizontal, QtCore.QVariant( self.filterForm.getField( self.columnNames[i] ).GetTitle() ))
+			if self.columnNames[i]=='stato':
+				myfieldinstance = self.filterForm.getField( self.columnNames[i] )
+				print "myfieldinstance:",myfieldinstance
+				myitemdelegate = SearchWidgetItemDelegate(myfieldinstance)
+				self.widgetList.setItemDelegateForColumn( i+1, myitemdelegate )
+			# TEST
+			#if self.columnNames[i]=='stato':
+				#myitemdelegate = SearchWidgetItemDelegate(myfield)
+				#self.widgetList.setItemDelegateForColumn( i+1, myitemdelegate )
 		self.widgetList.setModel( self.model )
 		self.verticalLayout.addWidget(self.widgetList,1)
 		# Slots
@@ -165,11 +208,21 @@ class SearchWidget(QtGui.QWidget):
 		self.widgetList.resizeRowsToContents()
 		self.emit(QtCore.SIGNAL("updatedList()"))
 	def _formToRow(self,row,myform):
+		readOnlyColumnNames = myform.getDetailReadOnlyColumnNames()
+		icon = QtGui.QIcon()
+		icon.addPixmap(QtGui.QPixmap(_fromUtf8(":/rPrj/%s"%myform.getDetailIcon())), QtGui.QIcon.Normal, QtGui.QIcon.Off)
+		self.model.setData(self.model.index(row, 0), u"%s"%myform.getDetailTitle() )
+		self.model.item(row,0).setEditable(False)
+		self.model.item(row,0).setIcon( icon )
 		for i in range(len(self.columnNames)):
 			myfield = myform.getField(self.columnNames[i])
 			myvalue = "%s"%myfield.getValue()
-			self.model.setData(self.model.index(row, i), myvalue )
-			self.model.setData(self.model.index(row, i), QtCore.QVariant(row), 32 )
+			self.model.setData(self.model.index(row, i+1), myvalue )
+			self.model.setData(self.model.index(row, i+1), QtCore.QVariant(row), 32 )
+			if self.columnNames[i] in readOnlyColumnNames:
+				self.model.item(row,i+1).setEditable(False)
+			else:
+				self.model.item(row,i+1).setEditable(True)
 # ############################## LOGIC ###################################
 	def runSearch(self,searchdbe):
 		"""A better name..."""
@@ -196,8 +249,6 @@ class SearchWidget(QtGui.QWidget):
 		cerca.setValuesDictionary( searchValues )
 		self.runSearch(cerca)
 	def slotItemClicked(self,item):
-		#print "SearchWidget.slotItemClicked: item=%s" % ( item )
-		#print "SearchWidget.slotItemClicked: item.data=%s" % ( item.data(QtCore.Qt.UserRole).toPyObject() )
 		pass
 	def slotItemDoubleClicked(self,item):
 		mydata = item.data(QtCore.Qt.UserRole).toPyObject()
